// note tones
#include "notes.h"
#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
 #include <avr/power.h> // Required for 16 MHz Adafruit Trinket
#endif

// Arduino pin connected to NeoPixel
#define PIN 6

// Size of NeoPixel ring
#define NUMPIXELS 16
// NeoPixel object
Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);

const int speakerPin = 3;
const int pirPin = A1;
const int photocellPin = A2;
const int thermistorPin = A3;
bool isHot = false;  // check for temp
bool isBright = false;  // check for light
bool isMoving = false; // check for motion

void setup() {
  Serial.begin(9600);
 
  pixels.begin(); // Initialize NeoPixel strip object

  Serial.println("Program starts");
}

// melody to play when conditions are met
int melody[] = {
  // The Lick 
  NOTE_D4,8, NOTE_E4,8, NOTE_F4,8, NOTE_G4,8, NOTE_E4,4, NOTE_C4,8, NOTE_D4,1,
  
};

// variables for playing the right tone
const int notes = sizeof(melody) / sizeof(melody[0]) / 2;
const int tempo = 140;
const int wholenote = (60000 * 2) / tempo;

// plays a tone on the speaker
void playMelody() {
  for(int thisNote = 0; thisNote < notes * 2; thisNote = thisNote + 2) {
    int divider = melody[thisNote + 1];
    int noteDuration = (divider > 0) ? wholenote / divider : (wholenote / abs(divider)) * 1.5;
    tone(speakerPin, melody[thisNote], noteDuration * 0.9);
    delay(noteDuration);
    noTone(speakerPin);
  }
}
 
void loop(){
  // check if the temperature is over 20 degrees celsius
  float temp = analogRead(thermistorPin);
  // provided formula to convert resistance to temp
  temp = 100 * temp / 1023 * 5 - 50;
  if(temp > 20) {
    isHot = true;
  } else {
    isHot = false;
  }

  Serial.print("\n temperature ");
  Serial.println(temp);

  // check if room light is too bright
  float light = analogRead(photocellPin);
  if(light > 800){
    isBright = true;
  } else {
    isBright = false;
  }
  Serial.print("\n light levels ");
  Serial.println(light);

  // check if someone is moving infront of sensor
  int motion = digitalRead(pirPin);
  if(motion == 1){
    isMoving = true;
  } else {
    isMoving = false;
  }

  Serial.print("\n Motion ");
  Serial.println(motion);  

  // conditions for turning on LED/playing melody (check user guide)
  if(!isMoving && isHot && isBright) {
    turnOnLED();
    playMelody();
  } else if(!isMoving && isHot) {
    motionLED();
    tempLED();
  } else if(!isMoving && isBright) {
    motionLED();
    lightLED();
  } else if(isHot && isBright) {
    tempLED();
    lightLED();
  } else if(!isMoving) {
    motionLED();
  } else if(isHot) {
    tempLED();
  } else if(isBright) {
    lightLED();
  } else {
    pixels.clear();
  }

  pixels.show();
  delay(100);
}

// turn on all leds (red, green, blue)
void turnOnLED(){
  motionLED();
  tempLED();
  lightLED();
}

// green light
void motionLED() {
  for(int i=0; i < 6; i++) {
    pixels.setPixelColor(i, pixels.Color(0, 255, 0));
  }
}

// blue light
void tempLED() {
  for(int i=6; i < 11; i++) {
    pixels.setPixelColor(i, pixels.Color(0, 0, 255)); 
  }
}

// red light
void lightLED() {
  for(int i=11; i < 16; i++) { 
    pixels.setPixelColor(i, pixels.Color(150, 0, 0));
  }
}